==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/ScatterLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ScatterBaseDescriptionMetadata } from "./ScatterBaseDescriptionMetadata";
import { ScatterLineSeriesDescription } from "./ScatterLineSeriesDescription";
/**
 * @hidden
 */
var ScatterLineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterLineSeriesDescriptionMetadata, _super);
    function ScatterLineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ScatterLineSeriesDescriptionMetadata.b = function (a) {
        if (ScatterLineSeriesDescriptionMetadata.a == null) {
            ScatterLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ScatterLineSeriesDescriptionMetadata.c(ScatterLineSeriesDescriptionMetadata.a);
        }
        if (a.g(ScatterLineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(ScatterLineSeriesDescriptionMetadata.a);
    };
    ScatterLineSeriesDescriptionMetadata.c = function (a) {
        ScatterBaseDescriptionMetadata.c(a);
        a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
        a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
    };
    ScatterLineSeriesDescriptionMetadata.d = function (a) {
        ScatterLineSeriesDescriptionMetadata.b(a);
        a.u("ScatterLineSeries", function () { return new ScatterLineSeriesDescription(); });
        a.t("ScatterLineSeries", ScatterLineSeriesDescriptionMetadata.a);
    };
    ScatterLineSeriesDescriptionMetadata.$t = markType(ScatterLineSeriesDescriptionMetadata, 'ScatterLineSeriesDescriptionMetadata');
    ScatterLineSeriesDescriptionMetadata.a = null;
    return ScatterLineSeriesDescriptionMetadata;
}(Base));
export { ScatterLineSeriesDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ScatterLineSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ScatterBaseDescriptionMetadata } from "./ScatterBaseDescriptionMetadata";
import { ScatterLineSeriesDescription } from "./ScatterLineSeriesDescription";
/**
 * @hidden
 */
var ScatterLineSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterLineSeriesDescriptionMetadata, _super);
    function ScatterLineSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ScatterLineSeriesDescriptionMetadata.b = function (a) {
        if (ScatterLineSeriesDescriptionMetadata.a == null) {
            ScatterLineSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ScatterLineSeriesDescriptionMetadata.c(ScatterLineSeriesDescriptionMetadata.a);
        }
        if (a.j(ScatterLineSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(ScatterLineSeriesDescriptionMetadata.a);
    };
    ScatterLineSeriesDescriptionMetadata.c = function (a) {
        ScatterBaseDescriptionMetadata.c(a);
        a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
        a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
    };
    ScatterLineSeriesDescriptionMetadata.d = function (a) {
        ScatterLineSeriesDescriptionMetadata.b(a);
        a.aa("ScatterLineSeries", function () { return new ScatterLineSeriesDescription(); });
        a.z("ScatterLineSeries", ScatterLineSeriesDescriptionMetadata.a);
    };
    ScatterLineSeriesDescriptionMetadata.$t = markType(ScatterLineSeriesDescriptionMetadata, 'ScatterLineSeriesDescriptionMetadata');
    ScatterLineSeriesDescriptionMetadata.a = null;
    return ScatterLineSeriesDescriptionMetadata;
}(Base));
export { ScatterLineSeriesDescriptionMetadata };
